# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""empty message

Revision ID: 46ba6aaaac97
Revises: ('705732c70154', 'e3970889f38e')
Create Date: 2018-07-23 11:20:54.929246

"""

# revision identifiers, used by Alembic.
revision = "46ba6aaaac97"
down_revision = ("705732c70154", "e3970889f38e")


def upgrade():
    pass


def downgrade():
    pass
